# import sys
# import os
# # 将项目根目录添加到 Python 路径
# sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
# import re
# import pytest

# from grapher.network import NetworkXGraph

# @pytest.fixture
# def network():
#     canva = Canvas(file_path='test/模拟资质认证.canvas')
#     yield canva
#     canva.to_file(file_path='test/模拟资质认证output.canvas')

